@@ -58,13 +58,16 @@ STRUCTURE = Nav(
 			children=[
 				Nav(lazy_gettext("Adeliz, the Cinder Wind")),
 				Nav(lazy_gettext("Aminatou, the Fateshifter")),
+				Nav(lazy_gettext("Arcades, the Strategist")),
 				Nav(lazy_gettext("Isamaru, Hound of Konda")),
+				Nav(lazy_gettext("Galazeth Prismari")),
 				Nav(lazy_gettext("Golos, Tireless Pilgrim")),
 				Nav(lazy_gettext("Grenzo, Dungeon Warden")),
 				Nav(lazy_gettext("Kelsien, the Plague")),
 				Nav(lazy_gettext("Kess, Dissident Mage")),
 				Nav(lazy_gettext("Kinnan, Bonder Prodigy")),
 				Nav(lazy_gettext("Magda, Brazen Outlaw")),
+				Nav(lazy_gettext("Miara / Tevesh")),
 				Nav(lazy_gettext("Minsc, Beloved Ranger")),
 				Nav(lazy_gettext("Orvar, the All-Form")),
 				Nav(lazy_gettext("Rowan and Will Kenrith")),
